@@ -7,12 +7,14 @@ import logging
 
 class SQServer:
 
-	def __init__(self, host="127.0.0.1", port=1234, wconn=5, max_len=10240, action_len=3, str_queue=False, debug=False, logger=None):
+	def __init__(self, host="127.0.0.1", port=1234, wconn=5, max_len=10240, action_len=3, str_queue=False, debug=False,
+				 debug_wait=False, logger=None):
 		self.lock = Lock()
 		self.q = []
 		self.action_len = action_len
 		self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 		self.debug = debug
+		self.debug_wait = debug_wait
 		self.str_queue = str_queue
 		if not logger:
 			logger = logging.getLogger(__name__)
@@ -72,14 +74,14 @@ class SQServer:
 		:return:
 		"""
 		if self.debug:
-			self.logger.debug("other_actions> "+str(action_msg))
+			self.logger.debug("other_actions> " + str(action_msg))
 
 	def listen_single(self):
 		self.socket.listen(self.wconn)
-		if self.debug:
+		if self.debug_wait:
 			self.logger.debug("SERVER> Waiting for client...")
 		conn, addr = self.socket.accept()  # Accept connection when client connects
-		if self.debug:
+		if self.debug_wait:
 			self.logger.debug("SERVER> Connected by %s" % str(addr))
 		action_msg = conn.recv(self.max_len)  # Receive client data
 		action = action_msg[:self.action_len]
